FlutterOpenStreetMap class

Inheritance

Constructors

FlutterOpenStreetMap({Key? key, double buttonHeight = 50, double buttonWidth = 300, Color locationIconColor = Colors.blue, IconData locationIcon = Icons.location_pin, Color buttonforegroundColor = Colors.white, TextStyle buttonTextStyle = const TextStyle(fontSize: 18), String buttonText = "Set Current Location", required LatLong center, required void onPicked(PickedData pickedData), Color? primaryColor, bool? showZoomButtons})

Properties

buttonforegroundColor → Color
final
buttonHeight → double
final
buttonText → String
final
buttonTextStyle → TextStyle
final
buttonWidth → double
final
center → LatLong
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locationIcon → IconData
final
locationIconColor → Color
final
onPicked → void Function(PickedData pickedData)
final
primaryColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showZoomButtons → bool?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FlutterOpenStreetMap>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited