PickedData class

Constructors

PickedData({required LatLong latLong, required String addressName, required Map<String, dynamic> address})
const
PickedData.fromMap(Map<String, dynamic> map)
factory

Properties

address → Map<String, dynamic>
final
addressName → String
final
hashCode → int
The hash code for this object.
no setteroverride
latLong → LatLong
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({LatLong? latLong, String? addressName, Map<String, dynamic>? address}) → PickedData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override